//#include "StdAfx.h"
#include "DFComUtils.h"
#include <string.h>

// Prueft ob die uebergebene Firmwareversion unterstuetzt wird
int CDFComUtils::CheckVersionFirmware(char *version)
{
	// Unterstuetzung von:
	// 03.01. [00 .. MAX_BUILD_AEIII]
	// 04.00. [00 .. MAX_BUILD_AEIV_00]
	// 04.01. [00 .. MAX_BUILD_AEIV_01]
	int res = 0;

	// Versionsstring faengt mit 03.01. an?
	if (strstr(version, "03.01.") == version) {

		if (((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIII) {

			res = 1;
		}
	} else // Versionsstring faengt mit 04.00. an?
	if (strstr(version, "04.00.") == version) {

		if (((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_00) {

			res = 1;
		}
	} else // Versionsstring faengt mit 04.01. an?
	if (strstr(version, "04.01.") == version) {

		if (((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_01) {

			res = 1;
		}
	}

	return res;
}

// Prueft ob die uebergebene Firmwareversion unterstuetzt wird
int CDFComUtils::CheckVersionFirmwareOld(char *version)
{
	// Unterstuetzung von:
	// 03.01. [00 .. 21]
	// 04.00. [00 .. 21]
	int res = 0;

	// Versionsstring faengt mit 03.01. an?
	if (strstr(version, "03.01.") == version) {

		// Es gibt die Version 03.01.20.01 die noch
		// Zutritt und MDE unterstuetzt und auch die Versionsnummer liefert.
		if ((((unsigned char)version[6] - 0x30) * 10 + ((unsigned char)version[7] - 0x30)) < 21) {

			res = 1;
		}
	}

	return res;
}

// Prueft ob die uebergebene Firmwareversion unterstuetzt wird
// Prueft ob die aktuelle Zutrittskontrolle unterstuetzt wird
int CDFComUtils::CheckVersionFirmwareZK(char *version)
{
	// Unterstuetzung von:
	// 04.01. [01]
	int res = 0;

	 // Versionsstring faengt mit 04.01. an?
	if (strstr(version, "04.01.") == version && strstr(version, "PZE")) {

		if (((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_01) {

			res = 1;
		}
	}

	return res;
}

// Prueft ob die erste Zutrittskontrolle unterstuetzt wird.
int CDFComUtils::CheckVersionFirmwareZKOld(char *version)
{
	// Unterstuetzung von:
	// 03.01. [00 .. 21]
	// 04.00. [00 .. 21]
	int res = 0;

	// Versionsstring faengt mit 03.01. an?
	if (strstr(version, "03.01.") == version) {

		if ((((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIII) && strstr(&version[8], "ZK")) {

			res = 1;
		}
	} else // Versionsstring faengt mit 04.00. an?
	if (strstr(version, "04.00.") == version) {

		if (((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_00) {

			res = 1;
		}
	}

	return res;
}

// Prueft ob die erste Zutrittskontrolle unterstuetzt wird.
int CDFComUtils::CheckZK1(char *version)
{
	// Unterstuetzung von:
	// 03.01.xx
	// 04.00.xx
	int res = 0;

	// Versionsstring faengt mit 03.01. an?
	if (strstr(version, "03.01.") == version) {

		if ((((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIII) && strstr(&version[8], "ZK")) {

			res = 1;
		}
	} else // Versionsstring faengt mit 04.00. an?
	if (strstr(version, "04.00.") == version) {

		if (((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_00) {

			res = 1;
		}
	}

	return res;
}

// Prueft ob die erste Zutrittskontrolle unterstuetzt wird.
int CDFComUtils::CheckZK2(char *version)
{
	// Unterstuetzung von:
	// 04.01.xx.PZE
	// 04.01.xx.ZK
	// 04.01.xx.BDE
	// 04.01.xx.MDE
	int res = 0;

	// Versionsstring faengt mit 04.01. an?
	if (strstr(version, "04.01.") == version) {

		if ((((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_01) && strstr(&version[8], "PZE")) {

			res = 1;
		}
	} else // Versionsstring faengt mit 04.01. an?
	if (strstr(version, "04.01.") == version) {

		if ((((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_01) && strstr(&version[8], "ZK")) {

			res = 1;
		}
	} else // Versionsstring faengt mit 04.01. an?
	if (strstr(version, "04.01.") == version) {

		if ((((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_01) && strstr(&version[8], "BDE")) {

			res = 1;
		}
	} else // Versionsstring faengt mit 04.01. an?
	if (strstr(version, "04.01.") == version) {

		if ((((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_01) && strstr(&version[8], "MDE")) {

			res = 1;
		}
	}

	return res;
}

// Prueft ob die erste MDE unterstuetzt wird.
int CDFComUtils::CheckMDE(char *version)
{
	// Unterstuetzung von:
	// 03.01.xx (kein ZK im String)
	// 04.01.xx.BDE
	// 04.01.xx.MDE
	int res = 0;

	// Versionsstring faengt mit 03.01. an?
	if (strstr(version, "04.01.") == version) {

		if ((((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIII) && (strstr(&version[8], "ZK") == NULL)) {

			res = 1;
		}
	} else // Versionsstring faengt mit 04.01. an?
	if (strstr(version, "04.01.") == version) {

		if ((((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_01) && strstr(&version[8], "BDE")) {

			res = 1;
		}
	} else // Versionsstring faengt mit 04.01. an?
	if (strstr(version, "04.01.") == version) {

		if ((((version[6] - 0x30) * 10 + (version[7] - 0x30)) <= MAX_BUILD_AEIV_01) && strstr(&version[8], "MDE")) {

			res = 1;
		}
	}

	return res;
}


